@@ -59,6 +59,8 @@ class CommandHandler:
   def reduce_lv(self, lvpath, new_size_extents, test=False): 
     cmd_args = list()
     cmd_args.append(LVREDUCE_BIN_PATH)
+    cmd_args.append("--config")
+    cmd_args.append("'log{command_names=0}'")    
     if test:
       cmd_args.append('--test')
     cmd_args.append('-f')
@@ -78,6 +80,8 @@ class CommandHandler:
   def extend_lv(self, lvpath, new_size_extents, test=False): 
     cmd_args = list()
     cmd_args.append(LVEXTEND_BIN_PATH)
+    cmd_args.append("--config")
+    cmd_args.append("'log{command_names=0}'")    
     if test:
       cmd_args.append('--test')
     cmd_args.append('-l')
@@ -95,6 +99,8 @@ class CommandHandler:
   def activate_lv(self, lvpath):
     cmd_args = list()
     cmd_args.append(LVCHANGE_BIN_PATH)
+    cmd_args.append("--config")
+    cmd_args.append("'log{command_names=0}'")    
     cmd_args.append('-ay')
     cmd_args.append(lvpath)
     cmdstr = ' '.join(cmd_args)
@@ -105,6 +111,8 @@ class CommandHandler:
   def deactivate_lv(self, lvpath):
     cmd_args = list()
     cmd_args.append(LVCHANGE_BIN_PATH)
+    cmd_args.append("--config")
+    cmd_args.append("'log{command_names=0}'")    
     cmd_args.append('-an')
     cmd_args.append(lvpath)
     cmdstr = ' '.join(cmd_args)
@@ -115,6 +123,8 @@ class CommandHandler:
   def add_mirroring(self, lvpath, pvlist=[]):
     cmd_args = list()
     cmd_args.append(LVCONVERT_BIN_PATH)
+    cmd_args.append("--config")
+    cmd_args.append("'log{command_names=0}'")    
     cmd_args.append('-m1')
     cmd_args.append(lvpath)
     for pv in pvlist:
@@ -128,6 +138,8 @@ class CommandHandler:
   def remove_mirroring(self, lvpath):
     cmd_args = list()
     cmd_args.append(LVCONVERT_BIN_PATH)
+    cmd_args.append("--config")
+    cmd_args.append("'log{command_names=0}'")    
     cmd_args.append('-m0')
     cmd_args.append(lvpath)
     cmdstr = ' '.join(cmd_args)
@@ -164,6 +176,8 @@ class CommandHandler:
   def add_unalloc_to_vg(self, pv, vg):
     args = list()
     args.append(VGEXTEND_BIN_PATH)
+    args.append("--config")
+    args.append("'log{command_names=0}'")    
     args.append(vg.strip())
     args.append(pv.strip())
     cmdstr = ' '.join(args)
@@ -207,6 +221,8 @@ class CommandHandler:
   def remove_vg(self, vgname):
     args = list()
     args.append(VGCHANGE_BIN_PATH)
+    args.append("--config")
+    args.append("'log{command_names=0}'")    
     args.append("-a")
     args.append("n")
     args.append(vgname.strip())
@@ -219,6 +235,8 @@ class CommandHandler:
     commandstring = VGREMOVE_BIN_PATH + " " + vgname
     args_list = list()
     args_list.append(VGREMOVE_BIN_PATH)
+    args_list.append("--config")
+    args_list.append("'log{command_names=0}'")    
     args_list.append(vgname)
     cmdstring = ' '.join(args)
     outs,errs,result = execWithCaptureErrorStatusProgress(VGREMOVE_BIN_PATH,args_list,
@@ -229,6 +247,8 @@ class CommandHandler:
   def remove_pv(self, pvname):
     args = list()
     args.append(PVREMOVE_BIN_PATH)
+    args.append("--config")
+    args.append("'log{command_names=0}'")    
     args.append(pvname.strip())
     cmdstr = ' '.join(args)
     out,err,res = execWithCaptureErrorStatusProgress(PVREMOVE_BIN_PATH,args,
@@ -237,10 +257,14 @@ class CommandHandler:
       raise CommandError('FATAL', COMMAND_FAILURE % ("pvremove",cmdstr,err))
 
   def remove_lv(self, lvpath):
-    self.deactivate_lv(lvpath)
+    if self.is_snapshot(lvpath) == False:
+      self.deactivate_lv(lvpath)
+      
     try:
       args = list()
       args.append(LVREMOVE_BIN_PATH)
+      args.append("--config")
+      args.append("'log{command_names=0}'")    
       args.append("--force")
       args.append(lvpath.strip())
       cmdstr = ' '.join(args)
@@ -255,6 +279,8 @@ class CommandHandler:
   def rename_lv(self, vgname, lvname_old, lvname_new):
     args = list()
     args.append(LVRENAME_BIN_PATH)
+    args.append("--config")
+    args.append("'log{command_names=0}'")    
     args.append(vgname)
     args.append(lvname_old)
     args.append(lvname_new)
@@ -278,6 +304,8 @@ class CommandHandler:
   def reduce_vg(self, vg, pv):
     args = list()
     args.append(VGREDUCE_BIN_PATH)
+    args.append("--config")
+    args.append("'log{command_names=0}'")    
     args.append(vg.strip())
     args.append(pv.strip())
     cmdstr = ' '.join(args)
@@ -291,6 +319,8 @@ class CommandHandler:
   def move_pv(self, pv, extents_from, data, background=False):
     args = list()
     args.append(PVMOVE_BIN_PATH)
+    args.append("--config")
+    args.append("'log{command_names=0}'")        
     # policy
     if data[1] != None:
       if data[1] == 0:
@@ -324,6 +354,8 @@ class CommandHandler:
   
   def complete_pvmove(self, background=False):
     args = [PVMOVE_BIN_PATH]
+    args.append("--config")
+    args.append("'log{command_names=0}'")
     if background:
       args.append('--background')
       out, err, res = execWithCaptureErrorStatus(PVMOVE_BIN_PATH, args)
@@ -382,3 +414,17 @@ class CommandHandler:
       return False
     execWithCaptureProgress('sleep', ['sleep', '1'], _('Rereading partition table'))
     return True
+  
+  def is_snapshot(self, lvpath):
+    arglist = list()
+    arglist = [LVM_BIN_PATH, 'lvs', '--config', "'log{command_names=0}'", "-o", "attr", "--noheadings", lvpath]
+
+    out, err, status = execWithCaptureErrorStatus(LVM_BIN_PATH, arglist)
+    
+    if status != 0:
+      return False
+      
+    if out.lstrip().startswith("s") == True:
+      return True
+    else:
+      return False
