@@ -1,6 +1,7 @@
 
 import sys
 import os
+import re
 
 import Filesystem
 
@@ -119,4 +120,16 @@ def get_all_paths(dev_path):
     if label != None:
         paths.append('LABEL=' + label)
 
+    ## in new distributions there is no link from /dev/vg/lv
+    ## to /dev/mapper/vg-lv - so we will try to map it directly
+    regex = re.compile("^/dev\/([^\/]*?)\/([^\/]*?)$")
+    append_paths = []
+    for p in paths:
+        r = regex.search(p)
+        if r != None:
+            append_paths.append("/dev/mapper/" + r.groups()[0].replace("-", "--") + "-" + r.groups()[1].replace("-", "--"))
+
+    if append_paths != None:
+        paths.extend(append_paths)
+
     return paths
