@@ -64,7 +64,10 @@ class Multipath:
             # get origin
             args = list()
             args.append(DMSETUP_BIN)
-            args.append('ls')
+            args.append('info')
+            args.append('-c')
+            args.append('-o name,major,minor')
+            args.append('--noheadings')
             cmdstr = ' '.join(args)
             o,e,r = execWithCaptureErrorStatus(DMSETUP_BIN, args)
             if r != 0:
@@ -72,10 +75,10 @@ class Multipath:
             origin = None
             origin_name = words[0].rstrip(':')
             for or_line in o.splitlines():
-                or_words = or_line.split()
+                or_words = or_line.split(':')
                 if or_words[0] == origin_name:
-                    major = or_words[1].strip('(').strip(',')
-                    minor = or_words[2].strip(')')
+                    major = or_words[1].strip()
+                    minor = or_words[2].strip()
                     for l in block_devices:
                         if l[1] == major and l[2] == minor:
                             origin = l[0]
