@@ -45,6 +45,7 @@ UNINITIALIZED_ENTITIES=_("Uninitialized Entities")
 PHYSICAL_VIEW=_("Physical View")
 LOGICAL_VIEW=_("Logical View")
 
+MAX_LV_FOR_BESTFIT = 100
                                                                                 
 #############################################################
 class Volume_Tab_View:
@@ -57,6 +58,8 @@ class Volume_Tab_View:
     self.height = 0
     self.glade_xml = glade_xml
 
+    self.try_not_best_fit = True
+
     ##Set up list structure
     self.treeview = self.glade_xml.get_widget('treeview1')
     self.treemodel = self.treeview.get_model()
@@ -135,6 +138,14 @@ class Volume_Tab_View:
     vgs = self.model_factory.get_VGs()
     if len(vgs) > 0:
         model.foreach(self.check_tree_items, [vgs[0].get_name()])
+        
+        lvs_count = 0
+        for vg in vgs:
+            lvs_count += len(vg.lvs)
+        if (lvs_count < MAX_LV_FOR_BESTFIT):
+            self.try_not_best_fit = False
+        else:
+            self.glade_xml.get_widget('best_fit_button').set_sensitive(False)            
     else:
         unallocs = self.model_factory.query_unallocated()
         if len(unallocs) > 0:
@@ -531,8 +542,11 @@ class Volume_Tab_View:
       
   
   def on_best_fit(self, obj):
+      if (self.try_not_best_fit == True):
+          return
+
       self.on_resize_drawing_area(None, None)
-      self.__set_zoom_buttons(self.display_view.set_best_fit())
+      self.__set_zoom_buttons(self.display_view.set_best_fit(self.try_not_best_fit))
       self.display_view.draw()
   
   def on_zoom_in(self, obj):
