@@ -140,12 +140,15 @@ class DisplayView:
         
         return (True, True)
     
-    def set_best_fit(self):
+    def set_best_fit(self, try_not_best_fit = False):
         if self.display == None:
             return (False, False)
-        
+
         self.display.respect_smallest_selectable_width(False)
-        
+
+        if try_not_best_fit == True:
+            return (False, False)        
+
         vis_w, vis_h = self.get_visible_size()
         pix_w, pix_h, u_label_h = self.display.minimum_pixmap_dimension(self.da)
         
