@@ -14,13 +14,10 @@ import signal
 import string
 import os
 
-from lvmui_constants import PROGNAME, INSTALLDIR
-
-#PROGNAME = "system-config-lvm"
-#INSTALLDIR="/usr/share/system-config-lvm"
+PROGNAME = "system-config-lvm"
+INSTALLDIR="/usr/share/system-config-lvm"
 VERSION = "@VERSION@"
 
-
 ### gettext ("_") must come before import gtk ###
 import gettext
 gettext.bindtextdomain(PROGNAME, "/usr/share/locale")
@@ -154,7 +151,9 @@ def initGlade():
                                                                                 
 def runFullGUI():
     glade_xml = initGlade()
+    gtk.window_set_default_icon_from_file(INSTALLDIR + '/pixmaps/lv_icon.png')
     app = glade_xml.get_widget('window1')
+    app.set_icon_from_file(INSTALLDIR + '/pixmaps/lv_icon.png')
     blvm = baselvm(glade_xml, app)
     app.show()
     app.connect("destroy", lambda w: gtk.main_quit())
